@@ -13,7 +13,7 @@
 #' @param nCPU The amount of cpu's to be used for peak detection. If set to '-1' all available cores minus 1 will be used.
 #' @param include_nearbyPeaks If set to TRUE small peaks in the tails of larger ones will be included in the peak data, see \link[MassSpecWavelet]{peakDetectionCWT}.
 #' @param raw_peakheight (default = FALSE) Whether to use the raw peak height of a peak instead of the optimal CWT coefficient (which is a measure for AUC).
-#' @param duplicate_detection_multiplier (default 1) In case users want to process other spectra besides NMR, this parameter will increase the limit for two peaks to be considered a duplicate detection. When dealing with more destorted spectra this parameter can be increased (recomended to not increase above 10). 
+#' @param duplicate_detection_multiplier (default 1) In case users want to process other spectra besides NMR, this parameter will increase the limit for two peaks to be considered a duplicate detection. When dealing with more distorted spectra this parameter can be increased (recommended to not increase above 10). 
 #'
 #' @return The peaks detected with the wavelets.
 #' 
@@ -45,7 +45,7 @@ getWaveletPeaks <- function(Y.spec, X.ppm, sample.labels = NULL, window.width =
                             raw_peakheight = FALSE, duplicate_detection_multiplier = 1) {
     
     # error checks and miscellaneous parameter fixing
-    for (w in 1:length(window.split)) {
+    for (w in seq_along(window.split)) {
         if (!window.split[w] %in% c(2, 4, 16, 32, 64)) {
             warning(paste(" 'window.split value", as.character(window.split[w]), "is not a power of 2 (max 64). It is set to the default: 4", 
                           sep = " "))
@@ -115,6 +115,15 @@ getWaveletPeaks <- function(Y.spec, X.ppm, sample.labels = NULL, window.width =
     }
     
     
+    if (any(is.na(X.ppm))) {
+        warning("X.ppm contains NA's, trying to remove these.")
+        Y.spec <- Y.spec[,!is.na(X.ppm)]
+        X.ppm <- X.ppm[!is.na(X.ppm)]
+    }
+    if(any(is.na(Y.spec))){
+        stop("Y.spec contains NA's. Don't know how to deal with these.")
+    }
+    
     
     if (is.null(sample.labels)) {
         sample.labels <- as.numeric(seq(from = 1, to = nSamp))
@@ -161,7 +170,7 @@ getWaveletPeaks <- function(Y.spec, X.ppm, sample.labels = NULL, window.width =
         WavPeaks <- list()
         currentSpec <- as.numeric(Y.spec[Parcounter, ])
         ppm_vector <- X.ppm.matrix[Parcounter, ]
-        for (kw in 1:length(window.split)) {
+        for (kw in seq_along(window.split)) {
             window.increment <- FFTwindow/window.split[kw]  # determine width of window increment
             nshifts <- ceiling(nPPM/window.increment) - window.split + 1  # determine how many increments there have to be
             
@@ -403,7 +412,7 @@ getWaveletPeaks <- function(Y.spec, X.ppm, sample.labels = NULL, window.width =
         if(all(levels(WaveletPeaks$Sample) == new.levels)){
             levels(WaveletPeaks$Sample) <- original.levels
         }else{
-            for(lv in 1:length(levels(WaveletPeaks$Sample))){
+            for(lv in seq_along(levels(WaveletPeaks$Sample))){
                 levelMatch <- which(new.levels == levels(WaveletPeaks$Sample)[lv] )
                 levels(WaveletPeaks$Sample)[lv] <- original.levels[levelMatch]
             }
